@@ -9,8 +9,8 @@ while (<>) {
 	s/^\s+//; s/\s+$//;
 	next if /^$/;
 
-	die "format error: $_" if not /^((?:xn--)?[a-z0-9]+)$/;
+	die "format error: $_" if not /^(xn--[a-z0-9-]+|[a-z]+)$/;
 
-	print qq|    ".$_",\n|;
+	print qq|    "$_",\n|;
 }
 
