@@ -9,13 +9,13 @@ while (<>) {
 	s/^\s+//; s/\s+$//;
 	next if /^$/;
 
-	die "format error: $_" unless
+	die "format error: $_" if not
 		(my ($a, $b, $c) = /^([a-z0-9.-]+)\s+([a-z0-9-]+)(?:\s+(.+))?$/);
 
 	if ($c) {
-		print qq(    { "$a",\t"$b",\t"$c" },\n);
+		print qq|    { "$a",\t"$b",\t"$c" },\n|;
 	} else {
-		print qq(    { "$a",\t"$b",\tNULL },\n);
+		print qq|    { "$a",\t"$b",\tNULL },\n|;
 	}
 }
 
