@@ -3,7 +3,7 @@
 
 /* String sent to RIPE servers - MUST NOT BE LONGER THAN FIVE CHARACTERS! */
 /* Do *NOT* change it if you don't know what you are doing! */
-#define IDSTRING "Md5.1"
+#define IDSTRING "Md5.2"
 
 #define HIDE_TO_THE_END  -3
 #define HIDE_DISABLED    -2
@@ -28,7 +28,8 @@ int japanese_locale(void);
 unsigned long myinet_aton(const char *);
 unsigned long asn32_to_long(const char *);
 int isasciidigit(const char);
-int domcmp(const char *, const char *);
+int endstrcaseeq(const char *, const char *);
+int in_domain(const char *, const char *);
 const char *is_new_gtld(const char *);
 int domfind(const char *, const char *[]);
 char *normalize_domain(const char *);
